package lineClient;

import java.io.*;
import java.net.*;

import java.util.Date;
import java.text.DateFormat;
import java.text.SimpleDateFormat;

/**
 * This class exemplifies how to connect to the LINE 0.5.2 server, and submit commands to solve LQN models. 
 * Copyright (c) 2012-2014, Imperial College London 
 * All rights reserved. 
 */
public class LINEClient_example {
	
	static Socket lineSocket = null;
    static PrintWriter out = null;
    static BufferedReader in = null;
    
	static String LQNpath = "//data//ofbizLB.xml";
    static String EXTpath = "//data//ofbizLB_REPHCox.xml";
    static boolean EXT = true; // whether to solve with EXT or not
    
    static String server = "localhost";
    static int port = 5463;
    
    public static void main(String[] args) throws IOException, InterruptedException {
    	for(int i = 1; i <= 3; i++){
	    	boolean connected = connect(); 
	    	if (connected){
	    		for(int j = 1; j <= 2; j++){
					submitJob();
	    		}
	    		disconnect();
	    	}
    	}
        terminate();
    }
    
    private static boolean connect(){
    	boolean connected = false;
    	try {
            lineSocket = new Socket(server, port);//open socket in machine server, (remote) port 5463
            //writer to the socket
            out = new PrintWriter(lineSocket.getOutputStream());
            //input from socket
            in = new BufferedReader(new InputStreamReader(lineSocket.getInputStream()));
            
            String resp = in.readLine();
            if(resp.equals("LINE READY") ){
            	System.out.println(resp); 
            	connected = true;
            }
            
        } catch (UnknownHostException e) {
            System.err.println("Don't know about host:"+server+".");
            System.exit(1);
        } catch (IOException e) {
            System.err.println("Couldn't get I/O for the connection to: "+server+".");
            System.exit(1);
        }
    	return connected;
    }
    
    private static void submitJob(){
        String lineCommand;
        DateFormat dateFormat = new SimpleDateFormat("yyyy/MM/dd HH:mm:ss");
        Date date;
       	String currentDir = System.getProperty("user.dir");

        if (!EXT){
        	// Example: LQN
    		lineCommand = "SOLVE "+currentDir+LQNpath;
        }else{
        	// Example: LQN + EXT
        	lineCommand = "SOLVE "+currentDir+LQNpath+" "+currentDir+EXTpath;
        }
        out.println(lineCommand);
        out.flush();
        
        try {
            date = new Date();
	        System.out.println("Sent time: "+dateFormat.format(date));
	        String resp = in.readLine();
	        date = new Date();
        	System.out.println(dateFormat.format(date)+" "+resp);
	        while (in.ready()){
	        	resp = in.readLine();
	        	date = new Date();
	        	System.out.println(dateFormat.format(date)+" "+resp);
	        }
        } catch (UnknownHostException e) {
            System.err.println("Don't know about host:"+server+".");
            System.exit(1);
        } catch (IOException e) {
            System.err.println("Couldn't get I/O for the connection to: "+server+".");
            System.exit(1);
        } 
    }
    
    
    private static void disconnect(){
        DateFormat dateFormat = new SimpleDateFormat("yyyy/MM/dd HH:mm:ss");
        Date date;
        boolean LINEclosed = false;
        String command = "CLOSE";
    	out.println(command);
        out.flush();
        try {
        	while (!LINEclosed){
		        String resp = in.readLine();
	        	if( resp.equals("LINE CLOSED") )
	        		LINEclosed = true;
	        	date = new Date();
	        	System.out.println(dateFormat.format(date)+" "+resp);
        	}
        } catch (UnknownHostException e) {
            System.err.println("Don't know about host:"+server+".");
            System.exit(1);
        } catch (IOException e) {
            System.err.println("Couldn't get I/O for the connection to: "+server+".");
            System.exit(1);
        } 
    }

        
    private static void terminate(){
    	connect();
    	boolean LINEclosed = false;
        String command = "QUIT";
    	out.println(command);
        out.flush();
        DateFormat dateFormat = new SimpleDateFormat("yyyy/MM/dd HH:mm:ss");
        try{
	        while (!LINEclosed){
	        	String resp = in.readLine();
	        	if( resp.equals("LINE STOP") )
	        		LINEclosed = true;
	        	Date date = new Date();
	        	System.out.println(dateFormat.format(date)+": "+resp);
	        	
	        }
	        //clean up by closing down sockets
	        out.close();
	        in.close();
	        lineSocket.close();
        }catch (UnknownHostException e) {
            System.err.println("Don't know about host:"+server+".");
            System.exit(1);
        } catch (IOException e) {
            System.err.println("Couldn't get I/O for the connection to: "+server+".");
            System.exit(1);
        }
    }

 
    
}
